﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading;
using System.Windows.Forms;
using Phidget22;
using Phidget22.Events;
using Phidget22.ExampleUtils;

namespace PressureSensor_Example {
	public partial class Form1 : Form {
		CommandLineOpen open;
        formCleaner cleaner;
        PressureSensor baro = null;
		private ErrorEventBox errorBox;

		public Form1() {
			open = new CommandLineOpen(this);
            cleaner = new formCleaner(this);
            InitializeComponent();
		}

		public Form1(String[] commandLine) {
			open = new CommandLineOpen(this);
            cleaner = new formCleaner(this);
            open.commandLine = commandLine;
			InitializeComponent();
		}

		private void Form1_Load(object sender, EventArgs e) {
			
			errorBox = new ErrorEventBox(this);
			baro = new PressureSensor();

			this.Size = this.MinimumSize;

			baro.Attach += baro_attach;
			baro.Detach += baro_detach;
			baro.Error += baro_error;
			baro.PressureChange += baro_change;

			open.openCmdLine(baro);
		}

		private void Form1_FormClosing(object sender, FormClosingEventArgs e) {
			baro.Close();
		}

		void baro_attach(object sender, Phidget22.Events.AttachEventArgs e) {
			phidgetInfoBox1.FillPhidgetInfo((Phidget)sender);

			PressureSensor attachedDevice = (PressureSensor)sender;

			try {
				dataIntervalTrk.Unit = "ms";
				dataIntervalTrk.trkText = dataIntervalTrk.minTxt = attachedDevice.MinDataInterval.ToString();
				dataIntervalTrk.Minimum = attachedDevice.MinDataInterval;
				dataIntervalTrk.maxTxt = attachedDevice.MaxDataInterval.ToString();
				dataIntervalTrk.Maximum = attachedDevice.MaxDataInterval;
				dataIntervalTrk.Value = attachedDevice.MinDataInterval;

				changeTriggerTrk.Unit = "kPa";
				changeTriggerTrk.minTxt = attachedDevice.MinPressureChangeTrigger.ToString();
				changeTriggerTrk.Minimum = attachedDevice.MinPressureChangeTrigger;
				changeTriggerTrk.Maximum = attachedDevice.MaxPressureChangeTrigger;
				changeTriggerTrk.maxTxt = attachedDevice.MaxPressureChangeTrigger.ToString();
				changeTriggerTrk.Value = attachedDevice.PressureChangeTrigger;
			} catch (PhidgetException ex) {
				errorBox.addMessage("Error initializing device: " + ex.Message);
			}

			settingsBox.Visible = true;
			outputBox.Visible = true;
		}
		void baro_detach(object sender, Phidget22.Events.DetachEventArgs e) {
			phidgetInfoBox1.Clear();
            cleaner.clean();

            settingsBox.Visible = false;
			outputBox.Visible = false;
		}
		void baro_error(object sender, Phidget22.Events.ErrorEventArgs e) {
			errorBox.addMessage(e.Description);
		}

		void baro_change(object sender, Phidget22.Events.PressureSensorPressureChangeEventArgs e) {
			try {
				barovalue.Text = e.Pressure.ToString() + " kPa";
			} catch (PhidgetException ex) { errorBox.addMessage("Error reading pressure: " + ex.Message); }
		}

		private void dataIntervalTrk_Scroll(object sender, EventArgs e) {
			if (MouseButtons != MouseButtons.Left) {
				try {
					baro.DataInterval = (int)dataIntervalTrk.Value;
				} catch (Exception ex) {
					errorBox.addMessage("Error setting data interval: " + ex.Message);
				}
			}
		}

		private void changeTriggertrk_Scroll(object sender, EventArgs e) {
			if (MouseButtons != MouseButtons.Left) {
				try {
					baro.PressureChangeTrigger = changeTriggerTrk.Value;
				} catch (Exception ex) {
					errorBox.addMessage("Error setting change trigger: " + ex.Message);
				}
			}
		}

		private void changeTriggertrk_MouseUp(object sender, MouseEventArgs e) {
			try {
				baro.PressureChangeTrigger = changeTriggerTrk.Value;
			} catch (Exception ex) {
				errorBox.addMessage("Error setting change trigger: " + ex.Message);
			}
		}

		private void dataIntervalTrk_MouseUp(object sender, MouseEventArgs e) {
			try {
				baro.DataInterval = (int)dataIntervalTrk.Value;
			} catch (Exception ex) {
				errorBox.addMessage("Error setting data interval: " + ex.Message);
			}
		}
	}
}
